==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/LogsAttributeRemapperType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

/** Type of logs attribute remapper. */
@JsonSerialize(using = LogsAttributeRemapperType.LogsAttributeRemapperTypeSerializer.class)
public class LogsAttributeRemapperType {

  public static final LogsAttributeRemapperType ATTRIBUTE_REMAPPER =
      new LogsAttributeRemapperType("attribute-remapper");

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("attribute-remapper"));

  private String value;

  public boolean isValid() {
    return allowedValues.contains(this.value);
  }

  LogsAttributeRemapperType(String value) {
    this.value = value;
  }

  public static class LogsAttributeRemapperTypeSerializer
      extends StdSerializer<LogsAttributeRemapperType> {
    public LogsAttributeRemapperTypeSerializer(Class<LogsAttributeRemapperType> t) {
      super(t);
    }

    public LogsAttributeRemapperTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(
        LogsAttributeRemapperType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonValue
  public String getValue() {
    return this.value;
  }

  public void setValue(String value) {
    this.value = value;
  }

  /** Return true if this LogsAttributeRemapperType object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    return this.value.equals(((LogsAttributeRemapperType) o).value);
  }

  @Override
  public int hashCode() {
    return Objects.hash(value);
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static LogsAttributeRemapperType fromValue(String value) {
    return new LogsAttributeRemapperType(value);
  }
}

==> datadog-api-client-2.28.0-sources.jar: com/datadog/api/client/v1/model/LogsAttributeRemapperType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.datadog.api.client.ModelEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/** Type of logs attribute remapper. */
@JsonSerialize(using = LogsAttributeRemapperType.LogsAttributeRemapperTypeSerializer.class)
public class LogsAttributeRemapperType extends ModelEnum<String> {

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("attribute-remapper"));

  public static final LogsAttributeRemapperType ATTRIBUTE_REMAPPER =
      new LogsAttributeRemapperType("attribute-remapper");

  LogsAttributeRemapperType(String value) {
    super(value, allowedValues);
  }

  public static class LogsAttributeRemapperTypeSerializer
      extends StdSerializer<LogsAttributeRemapperType> {
    public LogsAttributeRemapperTypeSerializer(Class<LogsAttributeRemapperType> t) {
      super(t);
    }

    public LogsAttributeRemapperTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(
        LogsAttributeRemapperType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonCreator
  public static LogsAttributeRemapperType fromValue(String value) {
    return new LogsAttributeRemapperType(value);
  }
}
